@@ -27,6 +27,7 @@
 #include "konqview.h"
 #include "konqsettingsxt.h"
 #include "konqurl.h"
+#include "konqclosedwindowsmanager.h"
 
 #include <KAboutData>
 #include <KCrash>
@@ -302,5 +303,7 @@ extern "C" Q_DECL_EXPORT int kdemain(int argc, char **argv)
     KonqSessionManager::self()->disableAutosave();
     KonqSessionManager::self()->deleteOwnedSessions();
 
+    KonqClosedWindowsManager::destroy();
+
     return ret;
 }
