@@ -33,6 +33,7 @@
 
 #include <kfileitem.h>
 #include <kparts/mainwindow.h>
+#include <KParts/PartActivateEvent>
 #include <kservice.h>
 
 #include "konqcombo.h"
@@ -365,7 +366,7 @@ public Q_SLOTS:
 
     void slotAddClosedUrl(KonqFrameBase *tab);
 
-    void slotConfigure();
+    void slotConfigure(QString startingModule = QString());
     void slotConfigureDone();
     void slotConfigureToolbars();
     void slotConfigureExtensions();
@@ -436,6 +437,8 @@ private Q_SLOTS:
 
     void slotOpenWith();
 
+    void updateProxyForWebEngine(bool updateProtocolManager = true);
+
 #if 0
     void slotGoMenuAboutToShow();
 #endif
